// this function verifies disk space in kilobytes
function verifyDiskSpace(dirPath, spaceRequired) {
  var spaceAvailable;

  // Get the available disk space on the given path
  spaceAvailable = fileGetDiskSpaceAvailable(dirPath);

  // Convert the available disk space into kilobytes
  spaceAvailable = parseInt(spaceAvailable / 1024);

  // do the verification
  if(spaceAvailable < spaceRequired) {
    logComment("Espace disque insuffisant : " + dirPath);
    logComment("  requis : " + spaceRequired + " Ko");
    logComment("  disponible : " + spaceAvailable + " Ko");
    return(false);
  }

  return(true);
}

// OS type detection
// which platform?
function getPlatform() {
  var platformStr;
  var platformNode;

  if('platform' in Install) {
    platformStr = new String(Install.platform);

    if (!platformStr.search(/^Macintosh/))
      platformNode = 'mac';
    else if (!platformStr.search(/^Win/))
      platformNode = 'win';
    else
      platformNode = 'unix';
  }
  else {
    var fOSMac  = getFolder("Mac System");
    var fOSWin  = getFolder("Win System");

    logComment("fOSMac: "  + fOSMac);
    logComment("fOSWin: "  + fOSWin);

    if(fOSMac != null)
      platformNode = 'mac';
    else if(fOSWin != null)
      platformNode = 'win';
    else
      platformNode = 'unix';
  }

  return platformNode;
}


var srDest = 810;
var err;
var fProgram;
var platformNode;

platformNode = getPlatform();
logComment("initInstall: platformNode=" + platformNode);
// end - OS type detection

// --- LOCALIZATION NOTE: translate only these ---
var prettyName = "Fran\u00e7ais";
var langcode = "fr";
var regioncode = "FR";
var chromeNode = langcode + "-" + regioncode;
// --- END LOCALIZABLE RESOURCES ---
var regName    = "locales/mozilla/" + chromeNode;
var chromeName = chromeNode + ".jar";
var regionFile = regioncode + ".jar";
var platformName = langcode + "-" + platformNode + ".jar";
var localeName = "locale/" + chromeNode + "/";
var regionName = "locale/" + regioncode + "/";

err = initInstall(prettyName, regName, "1.1");
logComment("initInstall: " + err);

fProgram = getFolder("Program");
logComment("fProgram: " + fProgram);

if (verifyDiskSpace(fProgram, srDest)) {
  var chromeType = LOCALE;
  var tellRestart = 0;
  if (platformNode == 'unix') {
    // DELAYED_CHROME is still needed on many unix systems for bug 109044; this needs a Mozilla restart!
    chromeType |= DELAYED_CHROME;
    tellRestart = 1;
  }
  err = addDirectory("","bin",fProgram,"");
  logComment("addDirectory() a retourn\u00e9 : " + err);

  if (err != SUCCESS) {
    logComment("addDirectory() pour " + fProgram + " a \u00e9chou\u00e9!");
 
    if (platformNode != 'unix') {
      // couldn't install globally, try installing to the profile
      // does not work with DELAYED_CHROME !!! (see comment above - bug 109044)
      resetError();
      chromeType |= PROFILE_CHROME;
      fProgram = getFolder("Profile");
      logComment("essaie l'installation dans le profil de l'utilisateur : " + fProgram);
      err = addDirectory("","bin",fProgram,"");
    }
    else {
      logComment("ne peut pas utiliser le profil de l'utilisateur \u00e0 cause du bug 109044");
    }
  }
 
  setPackageFolder(fProgram);
 
  // check return value
  if ((err == SUCCESS) || (err == REBOOT_NEEDED)) {
    var tellReboot = 0;
    if (err == REBOOT_NEEDED) {
      tellReboot = 1;
      resetError();
    }
    // register chrome
    var cf = getFolder(fProgram, "chrome/"+chromeName);
    var pf = getFolder(fProgram, "chrome/"+platformName);
    var rf = getFolder(fProgram, "chrome/"+regionFile);

    registerChrome(chromeType, cf, localeName + "autoconfig/");
    registerChrome(chromeType, cf, localeName + "chatzilla/");
    registerChrome(chromeType, cf, localeName + "communicator/");
    registerChrome(chromeType, cf, localeName + "content-packs/");
    registerChrome(chromeType, cf, localeName + "cookie/");
    registerChrome(chromeType, cf, localeName + "editor/");
    registerChrome(chromeType, cf, localeName + "embed/");
    registerChrome(chromeType, cf, localeName + "forms/");
    registerChrome(chromeType, cf, localeName + "global/");
    registerChrome(chromeType, cf, localeName + "help/");
    registerChrome(chromeType, cf, localeName + "inspector/");
    registerChrome(chromeType, cf, localeName + "messenger/");
    registerChrome(chromeType, cf, localeName + "messenger-mdn/");
    registerChrome(chromeType, cf, localeName + "messenger-smime/");
    registerChrome(chromeType, cf, localeName + "mozldap/");
    registerChrome(chromeType, cf, localeName + "navigator/");
    registerChrome(chromeType, cf, localeName + "necko/");
    registerChrome(chromeType, cf, localeName + "pipnss/");
    registerChrome(chromeType, cf, localeName + "pippki/");
    registerChrome(chromeType, cf, localeName + "venkman/");
    registerChrome(chromeType, cf, localeName + "wallet/");

    registerChrome(chromeType, pf, localeName + "global-platform/");
    registerChrome(chromeType, pf, localeName + "navigator-platform/");
    registerChrome(chromeType, pf, localeName + "communicator-platform/");

    if (platformNode == "win")
    {
      registerChrome(chromeType, pf, localeName + "messenger-mapi/");
    }

    registerChrome(chromeType, rf, regionName + "communicator-region/");
    registerChrome(chromeType, rf, regionName + "editor-region/");
    registerChrome(chromeType, rf, regionName + "global-region/");
    registerChrome(chromeType, rf, regionName + "messenger-region/");
    registerChrome(chromeType, rf, regionName + "navigator-region/");

    err = performInstall(); 
    logComment("performInstall() a retourn\u00e9 : " + err);
    if (err == SUCCESS) {
      if (tellReboot == 1) {
        alert("L'installation est termin\u00e9e. Vous devez RED\u00c9MARRER votre syst\u00e8me avant d'\u00eatre capable de s\u00e9lectionner cette langue via \u00c9dition > Pr\u00e9f\u00e9rences (Cat\u00e9gorie: Apparence > Langues/Contenu).");
      }
      else {
        if (tellRestart == 1) {
          alert("L'installation est termin\u00e9e. Apr\u00e8s un RED\u00c9MARRAGE DE VOTRE NAVIGATEUR, vous devriez \u00eatre capable de s\u00e9lectionner cette langue via \u00c9dition > Pr\u00e9f\u00e9rences (Cat\u00e9gorie: Apparence > Langues/Contenu).");
        }
        else  {
          alert("L'installation est termin\u00e9e. Vous devriez \u00eatre en mesure de s\u00e9lectionner cette traduction via le menu \u00c9dition > Pr\u00e9f\u00e9rences (Cat\u00e9gorie: Apparence > Langues/Contenu).");
        }
      }
    }
    else {
      alert("L'installation a \u00e9chou\u00e9. Le code d'erreur est " + err);
    }
  }
  else {
    cancelInstall(err);
    logComment("cancelInstall d\u00fb \u00e0 l'erreur : " + err);
    if (err == -202) {
      alert("L'installation a \u00e9t\u00e9 annul\u00e9e avec l'erreur " + err + ". Il semble que vous n'ayez pas la permission d'\u00e9crire dans le r\u00e9pertoire 'chrome' de Mozilla. S'il-vous-pla\u00eet, installez comme root / administrateur syst\u00e8me.");
    }
    else {
      alert("L'installation a \u00e9t\u00e9 annul\u00e9e. Le code d'erreur est " + err);
    }
  }
}
else
  cancelInstall(INSUFFICIENT_DISK_SPACE);
